@@ -65,11 +65,9 @@ def retrieve_nosec_lines(
 def main(command_line_args=sys.argv[1:]):  # noqa: C901
     args = parse_args(command_line_args)
 
-    ui_mode = UImode.NORMAL
+    ui_mode = UImode.TRIM
     if args.interactive:
         ui_mode = UImode.INTERACTIVE
-    elif args.trim_reassigned_in:
-        ui_mode = UImode.TRIM
 
     files = discover_files(
         args.targets,
@@ -79,15 +77,19 @@ def main(command_line_args=sys.argv[1:]):  # noqa: C901
 
     nosec_lines = defaultdict(set)
 
-    for path in files:
+    if args.project_root:
+        directory = os.path.normpath(args.project_root)
+        project_modules = get_modules(directory, prepend_module_root=args.prepend_module_root)
+
+    cfg_list = list()
+    for path in sorted(files):
         if not args.ignore_nosec:
             nosec_lines[path] = retrieve_nosec_lines(path)
 
-        if args.project_root:
-            directory = os.path.normpath(args.project_root)
-        else:
+        if not args.project_root:
             directory = os.path.dirname(path)
-        project_modules = get_modules(directory, prepend_module_root=args.prepend_module_root)
+            project_modules = get_modules(directory, prepend_module_root=args.prepend_module_root)
+
         local_modules = get_directory_modules(directory)
         tree = generate_ast(path)
 
